@@ -23,7 +23,7 @@ def chunk_dict(d, n):
 @task()
 def doReset():
     lemmas = loadLemmas()
-    lemma_job = group(addLemmas.si(x) for x in chunk_dict(list(lemmas),10000))
+    lemma_job = group(addLemmas.si(x) for x in chunk_dict(lemmas,10000))
     wfs,spells,trans = loadWF()
     wf_job = group(addWFS.si(x) for x in chunk_dict(wfs,10000))
     spell_job = group(addSpells.si(x) for x in chunk_dict(spells,10000))
